from Plugins.Plugin import PluginDescriptor

from Screens.Screen import Screen
from Screens.InputBox import InputBox
from Screens.ChoiceBox import ChoiceBox
from Screens.MessageBox import MessageBox
from Components.ServicePosition import ServicePositionGauge
from Components.ActionMap import HelpableActionMap
from Components.MenuList import MenuList
from Components.MultiContent import MultiContentEntryText
from Components.ServiceEventTracker import ServiceEventTracker
from Components.ActionMap import ActionMap
from Components.Input import Input
from Screens.InfoBarGenerics import InfoBarSeek, InfoBarCueSheetSupport
from Components.GUIComponent import GUIComponent
from enigma import eListboxPythonMultiContent, eListbox, gFont, iPlayableService, RT_HALIGN_RIGHT, eServiceCenter, eServiceReference
from Screens.FixedMenu import FixedMenu
import os
plugin_version="2.1"


def main(session, service, **kwargs):
	session.open(Wastebasket, service)

def Plugins(**kwargs):
 	return PluginDescriptor(name="Movie Wastebasket", description=_("Wastebasket ..."), where = PluginDescriptor.WHERE_MOVIELIST, fnc=main)


class Wastebasket(Screen):
    skin = """
        <screen position="150,200" size="400,200" title="Movie Wastebasket Menu" >
            <widget name="menu" position="10,10" size="390,190" scrollbarMode="showOnDemand" />
        </screen>"""
        
    def __init__(self, session, service, args = 0):
        self.skin = Wastebasket.skin
        self.session = session
        Screen.__init__(self, session)
        self.menu = args
        list = []
        list.append((_("restore wastebasket"), "restorewastebasket"))
        list.append((_("empty wastebasket"), "emptywastebasket"))
        list.append((_("about"), "aboutwastebasket"))        
        self["menu"] = MenuList(list)
        self["actions"] = ActionMap(["WizardActions", "DirectionActions"],{"ok": self.go,"back": self.close,}, -1)
        
    def go(self):
        returnValue = self["menu"].l.getCurrentSelection()[1]
        if  os.path.exists("/media/hdd/movie/wastebasket") is False:
           os.system("mkdir /media/hdd/movie/wastebasket")
        if returnValue is not None:
           if returnValue is "emptywastebasket":
              EmptyWastebasket(self.session)
           elif returnValue is "restorewastebasket":
              RestoreWastebasket(self.session)
           elif returnValue is "aboutwastebasket":
              self.session.open(MessageBox,_("Movie Wastebasket Enigma2 Plugin\nVersion %s by gutemine" % plugin_version), MessageBox.TYPE_INFO)
        

class EmptyWastebasket(Screen):
    def __init__(self, session):

        self.session = session
        self.session.openWithCallback(self.EmptyWastebasketConfirmed,MessageBox,_("are you sure to empty entire wastebasket ?"), MessageBox.TYPE_YESNO)

    def EmptyWastebasketConfirmed(self,answer):
        if answer is None:
            self.skipEmptyWastebasket("answer is None")
        if answer is False:
            self.skipEmptyWastebasket("you were not confirming")
        else:
            for filename in os.listdir("/media/hdd/movie/wastebasket"): 
                os.remove("/media/hdd/movie/wastebasket/%s" % filename)
            self.session.open(MessageBox,_("empty wastebasket completed !"), MessageBox.TYPE_INFO)
            
    def skipEmptyWastebasket(self,reason):
        self.session.open(MessageBox,_("empty wastebasket was cancelled, because %s" % reason), MessageBox.TYPE_WARNING)
        
        
class RestoreWastebasket(Screen):
    def __init__(self, session):

        self.session = session
        self.session.openWithCallback(self.askForRestore,ChoiceBox,_("select recording to restore"),self.getListWastebasket())

    def askForRestore(self,wastebasket):
        if wastebasket is None:
           self.skipRestoreWastebasket("answer is None")
        else:
           self.wastebasket = wastebasket[1]
           self.session.openWithCallback(self.RestoreWastebasketConfirmed,MessageBox,_("are you sure to restore %s ?" % self.wastebasket), MessageBox.TYPE_YESNO)

    def RestoreWastebasketConfirmed(self,answer):
        if answer is None:
            self.skipRestoreWastebasket("answer is None")
        if answer is False:
            self.skipRestoreWastebasket("you were not confirming")
        else:
            if self.wastebasket == "all":
               for filename in os.listdir("/media/hdd/movie/wastebasket"): 
                  os.link("/media/hdd/movie/wastebasket/%s" % filename, "/media/hdd/movie/%s" % filename)
                  os.remove("/media/hdd/movie/wastebasket/%s" % filename)
            else:
               for filename in os.listdir("/media/hdd/movie/wastebasket"): 
                  if filename.startswith(self.wastebasket) is True: 
                     os.link("/media/hdd/movie/wastebasket/%s" % filename, "/media/hdd/movie/%s" % filename)
                     os.remove("/media/hdd/movie/wastebasket/%s" % filename)
            
            self.session.open(MessageBox,_("restore wastebasket completed !"), MessageBox.TYPE_INFO)
            
    def skipRestoreWastebasket(self,reason):
        self.session.open(MessageBox,_("restore wastebasket was cancelled, because %s" % reason), MessageBox.TYPE_WARNING)
        
        
    def getListWastebasket(self):
        wastebasket = []
        wastebasket.append(( "all", "all" ))
        parts=[]
        for line in os.listdir("/media/hdd/movie/wastebasket"):
            if line.endswith(".ts") is True: 
               parts=line.rsplit(".ts",1)
               name=parts[0]
               wastebasket.append(( name, name ))
        return wastebasket
